assets2 = "https://github.com/kamangir/assets2/blob/main/bluer-fire"

dict_of_images = {}

items = [
    "[![image]({})]({})".format(image, url if url else image)
    for image, url in dict_of_images.items()
]



dict_of_parts = {
    "rpi3bp": "",
    "dc-motor-12-VDC-45W": "2 x rear + steering",
    "SLA-Battery": "",
    "XL4015": "",
    "BTS7960": "rear drive (2 motors) & steering drive (1 motor)",
    "470-mF": "",
    "Polyfuse": "",
    "TVS-diode": "",
    "330-ohm": "",
    "LED": "",
    "rpi-camera": "",
    "PCB-single-14x9_5": "",
    "PCB-double-9x7": "",
    "pushbutton": "",
}



assets2 = "https://github.com/kamangir/assets2/blob/main/bluer-eagle"

dict_of_images = {
    f"{assets2}/file_0000000007986246b45343b0c06325dd.png?raw=true": "",
    f"{assets2}/20250727_182113.jpg?raw=true": "",
    f"{assets2}/20250726_171953.jpg?raw=true": "",
}

items = [
    "[![image]({})]({})".format(image, url if url else image)
    for image, url in dict_of_images.items()
]
